<template>
  <div>
    <div>
      <div class="search">
        <div class="search_thing">
          <div class="search_label">日期：</div>
          <div class="search_input" style="display: flex; align-items: center">
            <el-date-picker
              v-model="queryParams.month"
              :clearable="false"
              format="yyyy-MM"
              placeholder="选择月"
              size="small"
              style="width: 100%"
              type="month"
              value-format="yyyy-MM"
              @change="refreshTable()"
            >
            </el-date-picker>
          </div>
        </div>
        <div class="search_thing">
          <div class="search_label">员工：</div>
          <el-input
            v-model="queryParams.name"
            clearable
            placeholder="请输入"
            size="small"
            @keyup.enter.native="refreshTable()"
          ></el-input>
        </div>
        <div class="search_thing" style="padding-left: 30px">
          <el-button size="small" @click="refresh()">重 置</el-button>
          <el-button size="small" type="primary" @click="refreshTable()"
            >查 询</el-button
          >
        </div>
      </div>
      <div class="table">
        <TableCard :showForm="false" :showTitle="false">
          <template v-slot:table>
            <limsTable
              :column="tableColumn"
              :table-data="tableData"
              :table-loading="tableLoading"
              :page="page"
              style="padding: 0 15px"
            >
            </limsTable>
          </template>
        </TableCard>
      </div>
    </div>
  </div>
</template>

<script>
import { getYearAndMonthAndDays } from "@/utils/date";
import TableCard from "@/components/TableCard/index.vue";
import limsTable from "@/components/Table/lims-table.vue";
import { selectAuxiliaryAllByMonth } from "@/api/performance/manHour";
export default {
  components: {
    limsTable,
    TableCard,
  },
  data() {
    return {
      queryParams: {
        month: getYearAndMonthAndDays().slice(0, 7),
        name: "",
        departLims: "",
      },
      tableColumn: [
        {
          label: "姓名",
          minWidth: "120px",
          prop: "userName",
        },
        {
          label: "月份",
          minWidth: "120px",
          prop: "month",
        },
        {
          label: "产量工时",
          minWidth: "120px",
          prop: "yieldHour",
        },
        {
          label: "辅助工时",
          minWidth: "120px",
          prop: "subsidiaryHour",
        },
        {
          label: "总工时",
          minWidth: "120px",
          prop: "totalHour",
        },
      ],
      tableData: [],
      tableLoading: false,
      page: {
        total: 0,
        size: 10,
        current: 0,
      },
    };
  },
  mounted() {
    this.refreshTable();
  },
  methods: {
    refreshTable() {
      this.tableLoading = true;
      selectAuxiliaryAllByMonth(this.queryParams)
        .then((res) => {
          this.tableLoading = false;
          if (res.code === 201) return;
          this.tableData = res.data;
        })
        .catch(() => {
          this.tableLoading = false;
        });
    },
    refresh() {
      this.queryParams = {
        month: getYearAndMonthAndDays().slice(0, 7),
        name: "",
        departLims: "",
      };
      this.refreshTable();
    },
    // 分页
    handleCurrent(page) {
      this.pagination.curent = page;
      this.refreshTable();
    },
    handleSizeChange(size) {
      this.pagination.pageSize = size;
      this.refreshTable();
    },
  },
};
</script>

<style scoped>
.work-time-statistics {
  height: 100%;
}
.search {
  background-color: #fff;
  height: 80px;
  display: flex;
  align-items: center;
}

.search_thing {
  width: 270px;
  display: flex;
  align-items: center;
}

.search_label {
  width: 60px;
  font-size: 14px;
  text-align: right;
}

.search_input {
  width: calc(100% - 60px);
}
.table {
  height: calc(100% - 60px - 80px - 10px - 40px - 25px);
}
</style>
